package com.wechi.adweb.bridge.google.gtm.service;

import com.google.api.client.googleapis.auth.oauth2.GoogleCredential;
import com.google.api.client.googleapis.javanet.GoogleNetHttpTransport;
import com.google.api.client.http.HttpTransport;
import com.google.api.client.json.gson.GsonFactory;
import com.google.api.services.tagmanager.TagManager;
import com.google.api.services.tagmanager.TagManagerScopes;

import jakarta.annotation.PostConstruct;

import lombok.extern.slf4j.Slf4j;

import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;

import java.io.IOException;
import java.security.GeneralSecurityException;

/**
 * @author wfansh
 */
@Slf4j
@Service
public class GTMService {

    @Value("${google.service.account.key}")
    private String serviceAccountKey;

    private TagManager tagManager;

    @PostConstruct
    private void init() throws GeneralSecurityException, IOException {
        // Service account authorization;
        HttpTransport httpTransport = GoogleNetHttpTransport.newTrustedTransport();
        GoogleCredential credential =
                GoogleCredential.fromStream(
                                this.getClass()
                                        .getClassLoader()
                                        .getResourceAsStream(serviceAccountKey))
                        .createScoped(TagManagerScopes.all());

        this.tagManager =
                new TagManager.Builder(httpTransport, GsonFactory.getDefaultInstance(), credential)
                        .build();
    }
}
